﻿using System;
using System.IO;
using System.Reflection;
using System.Threading.Tasks;
using System.Windows.Input;
using System.Windows.Threading;
using Telerik.Windows.Controls;
using Telerik.Windows.Documents.Fixed;

namespace WpfApplication15
{
    public class ViewModel : ViewModelBase
    {
        private bool _isBusy;
        private readonly DispatcherTimer _timer = new DispatcherTimer { Interval = TimeSpan.FromMilliseconds(1000) };
        private int _seconds;
        private PdfDocumentSource _pdfSource;
        public ICommand GoCommand { get; set; }

        public PdfDocumentSource PdfSource
        {
            get { return _pdfSource; }
            set
            {
                _pdfSource = value;
                OnPropertyChanged(() => PdfSource);
            }
        }

        public bool IsBusy
        {
            get { return _isBusy; }
            set
            {
                if (_isBusy != value)
                {
                    _isBusy = value;

                    if (_isBusy)
                    {
                        Seconds = 0;
                        _timer.Tick += OnTimerTick;
                        _timer.Start();
                    }
                    else
                    {
                        _timer.Tick -= OnTimerTick;
                        _timer.Stop();
                    }
                    OnPropertyChanged(() => IsBusy);
                }
            }
        }

        public string BusyContent
        {
            get { return string.Format("{0} seconds", Seconds); }
        }

        public int Seconds
        {
            get { return _seconds; }
            set
            {
                _seconds = value;
                OnPropertyChanged(() => Seconds);
                OnPropertyChanged(() => BusyContent);
            }
        }

        private void OnTimerTick(object sender, EventArgs e)
        {
            Seconds++;
        }

        public ViewModel()
        {
            GoCommand = new DelegateCommand(Go);
        }

        private async void Go(object obj)
        {
            IsBusy = true;
            PdfSource = null;
            await Task.Delay(3000);
            var assembly = Assembly.GetAssembly(GetType());
            var pdf = assembly.GetManifestResourceStream("WpfApplication15.ThisIsATest.pdf");
            var ms = new MemoryStream();
            if (pdf != null)
            {
                pdf.CopyTo(ms);
                PdfSource = new PdfDocumentSource(ms);
            }

            IsBusy = false;
        }
    }

}
